@@ -16,11 +16,10 @@ export LIBRARY_PATH="${PREFIX}/lib"
             --enable-fortran2003 \
             --with-default-plugindir="${PREFIX}/lib/hdf5/plugin" \
             --enable-threadsafe \
-            --enable-production \
+            --enable-build-mode=production \
             --enable-unsupported \
             --with-ssl
 
-#             --disable-static \
 make -j "${CPU_COUNT}"
 make check
 make install
